==> antlrworks-1.1.7-src.zip: src/plugin/org/antlr/works/plugin/container/PCMenuHelpDelegate.java <==
package org.antlr.works.plugin.container;

import org.antlr.xjlib.appkit.menu.XJMainMenuBar;
import org.antlr.xjlib.appkit.menu.XJMenu;
import org.antlr.xjlib.appkit.menu.XJMenuItem;
import org.antlr.xjlib.appkit.menu.XJMenuItemDelegate;
import org.antlr.works.IDE;
import org.antlr.works.editor.EditorMenu;
/*

[The "BSD licence"]
Copyright (c) 2005-2006 Jean Bovet
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.
3. The name of the author may not be used to endorse or promote products
derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*/

public class PCMenuHelpDelegate implements XJMenuItemDelegate {

    private PluginContainer container;

    public PCMenuHelpDelegate(PluginContainer pluginContainer) {
        this.container = pluginContainer;
    }

    public void handleMenuEvent(XJMenu menu, XJMenuItem item) {
        switch(item.getTag()) {
            case XJMainMenuBar.MI_ABOUT:
                PluginContainer.showAbout();
                break;
            case XJMainMenuBar.MI_HELP:
                IDE.showHelp(container.getParent());
                break;
            case EditorMenu.MI_SUBMIT_STATS:
                IDE.submitStats(container.getParent());
                break;
            case EditorMenu.MI_SEND_FEEDBACK:
                IDE.submitFeedback(container.getParent());
                break;
            case EditorMenu.MI_CHECK_UPDATES:
                IDE.checkUpdates(container.getParent());
                break;
        }
    }

}

==> antlrworks-1.2.2-src.zip: src/plugin/org/antlr/works/plugin/container/PCMenuHelpDelegate.java <==
package org.antlr.works.plugin.container;

import org.antlr.works.IDE;
import org.antlr.works.components.container.ComponentContainerGrammarMenu;
import org.antlr.xjlib.appkit.menu.XJMainMenuBar;
import org.antlr.xjlib.appkit.menu.XJMenu;
import org.antlr.xjlib.appkit.menu.XJMenuItem;
import org.antlr.xjlib.appkit.menu.XJMenuItemDelegate;
/*

[The "BSD licence"]
Copyright (c) 2005-2006 Jean Bovet
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.
3. The name of the author may not be used to endorse or promote products
derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*/

public class PCMenuHelpDelegate implements XJMenuItemDelegate {

    private PluginWindow window;

    public PCMenuHelpDelegate(PluginWindow pluginWindow) {
        this.window = pluginWindow;
    }

    public void handleMenuEvent(XJMenu menu, XJMenuItem item) {
        switch(item.getTag()) {
            case XJMainMenuBar.MI_ABOUT:
                PluginWindow.showAbout();
                break;
            case XJMainMenuBar.MI_HELP:
                IDE.showHelp(window.getParent());
                break;
            case ComponentContainerGrammarMenu.MI_SUBMIT_STATS:
                IDE.submitStats(window.getParent());
                break;
            case ComponentContainerGrammarMenu.MI_SEND_FEEDBACK:
                IDE.submitFeedback(window.getParent());
                break;
            case ComponentContainerGrammarMenu.MI_CHECK_UPDATES:
                IDE.checkUpdates(window.getParent());
                break;
        }
    }

}
